"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[60757],{55876(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a={lastWeek:"せんしゅうのeeeeのp",yesterday:"きのうのp",today:"きょうのp",tomorrow:"あしたのp",nextWeek:"よくしゅうのeeeeのp",other:"P"},r=function(e,t,r,u){return a[e]};t.default=r,e.exports=t.default}}]);
//# sourceMappingURL=60757.dtale_bundle.js.map