"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[47321],{44216(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a={lastWeek:"'të' eeee 'e shkuar në' p",yesterday:"'dje në' p",today:"'sot në' p",tomorrow:"'nesër në' p",nextWeek:"eeee 'at' p",other:"P"},r=function(e,t,r,n){return a[e]};t.default=r,e.exports=t.default}}]);
//# sourceMappingURL=47321.dtale_bundle.js.map