"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[98932],{53569(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a={lastWeek:"eeee 'tuần trước vào lúc' p",yesterday:"'hôm qua vào lúc' p",today:"'hôm nay vào lúc' p",tomorrow:"'ngày mai vào lúc' p",nextWeek:"eeee 'tới vào lúc' p",other:"P"},l=function(e,t,l,o){return a[e]};t.default=l,e.exports=t.default}}]);
//# sourceMappingURL=98932.dtale_bundle.js.map