"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[24443],{16042(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o={lastWeek:"'vorige' eeee 'om' p",yesterday:"'gisteren om' p",today:"'vandaag om' p",tomorrow:"'morgen om' p",nextWeek:"eeee 'om' p",other:"P"},a=function(e,t,a,r){return o[e]};t.default=a,e.exports=t.default}}]);
//# sourceMappingURL=24443.dtale_bundle.js.map