"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[47842],{7775(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var n=["vasárnap","hétfőn","kedden","szerdán","csütörtökön","pénteken","szombaton"];function r(e){return function(t){var r=n[t.getUTCDay()];return"".concat(e?"":"'múlt' ","'").concat(r,"' p'-kor'")}}var a={lastWeek:r(!1),yesterday:"'tegnap' p'-kor'",today:"'ma' p'-kor'",tomorrow:"'holnap' p'-kor'",nextWeek:r(!0),other:"P"},o=function(e,t){var n=a[e];return"function"==typeof n?n(t):n};t.default=o,e.exports=t.default}}]);
//# sourceMappingURL=47842.dtale_bundle.js.map