(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[48216],{12373(e){e.exports=function(e){return{name:"Backus–Naur Form",contains:[{className:"attribute",begin:/</,end:/>/},{begin:/::=/,end:/$/,contains:[{begin:/</,end:/>/},e.C_LINE_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,e.APOS_STRING_MODE,e.QUOTE_STRING_MODE]}]}}}}]);
//# sourceMappingURL=48216.dtale_bundle.js.map