(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[88705],{72841(a){a.exports=function(a){return{name:"Node REPL",contains:[{className:"meta",starts:{end:/ |$/,starts:{end:"$",subLanguage:"javascript"}},variants:[{begin:/^>(?=[ ]|$)/},{begin:/^\.\.\.(?=[ ]|$)/}]}]}}}}]);
//# sourceMappingURL=88705.dtale_bundle.js.map