"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[44514],{2479(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var l={lastWeek:"'sidste' eeee 'kl.' p",yesterday:"'i går kl.' p",today:"'i dag kl.' p",tomorrow:"'i morgen kl.' p",nextWeek:"'på' eeee 'kl.' p",other:"P"},a=function(e,t,a,r){return l[e]};t.default=a,e.exports=t.default}}]);
//# sourceMappingURL=44514.dtale_bundle.js.map