"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[95967],{89870(e,a){Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var t={lastWeek:"eeee 'passat a' p",yesterday:"'ièr a' p",today:"'uèi a' p",tomorrow:"'deman a' p",nextWeek:"eeee 'a' p",other:"P"},r=function(e,a,r,u){return t[e]};a.default=r,e.exports=a.default}}]);
//# sourceMappingURL=95967.dtale_bundle.js.map