(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[81895],{9507(a){a.exports=function(a){return{aliases:["pycon"],contains:[{className:"meta",starts:{end:/ |$/,starts:{end:"$",subLanguage:"python"}},variants:[{begin:/^>>>(?=[ ]|$)/},{begin:/^\.\.\.(?=[ ]|$)/}]}]}}}}]);
//# sourceMappingURL=81895.dtale_bundle.js.map