"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[16187],{87146(e,a){Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var t={lastWeek:"'geçen hafta' eeee 'saat' p",yesterday:"'dün saat' p",today:"'bugün saat' p",tomorrow:"'yarın saat' p",nextWeek:"eeee 'saat' p",other:"P"},s=function(e,a,s,r){return t[e]};a.default=s,e.exports=a.default}}]);
//# sourceMappingURL=16187.dtale_bundle.js.map