"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[41345],{81713(e,t,a){var n=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e,t,a){(0,i.default)(2,arguments);var n=(0,r.default)(e,a),u=(0,r.default)(t,a);return n.getTime()===u.getTime()};var i=n(a(10427)),r=n(a(20930));e.exports=t.default},89352(e,t,a){var n=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var i=n(a(81713)),r={masculine:"ostatni",feminine:"ostatnia"},u={masculine:"ten",feminine:"ta"},o={masculine:"następny",feminine:"następna"},f={0:"feminine",1:"masculine",2:"masculine",3:"feminine",4:"masculine",5:"masculine",6:"feminine"};function l(e,t,a,n){var l;if((0,i.default)(t,a,n))l=u;else if("lastWeek"===e)l=r;else{if("nextWeek"!==e)throw new Error("Cannot determine adjectives for token ".concat(e));l=o}var s=t.getUTCDay(),d=l[f[s]];return"'".concat(d,"' eeee 'o' p")}var s={lastWeek:l,yesterday:"'wczoraj o' p",today:"'dzisiaj o' p",tomorrow:"'jutro o' p",nextWeek:l,other:"P"},d=function(e,t,a,n){var i=s[e];return"function"==typeof i?i(e,t,a,n):i};t.default=d,e.exports=t.default}}]);
//# sourceMappingURL=41345.dtale_bundle.js.map