(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[42979],{81832(e){e.exports=function(e){return{name:"Plain text",aliases:["text","txt"],disableAutodetect:!0}}}}]);
//# sourceMappingURL=42979.dtale_bundle.js.map