(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[13419],{28520(e){e.exports=function(e){const n={keyword:"rec with let in inherit assert if else then",literal:"true false or and null",built_in:"import abort baseNameOf dirOf isNull builtins map removeAttrs throw toString derivation"},s={className:"subst",begin:/\$\{/,end:/\}/,keywords:n},t={className:"string",contains:[s],variants:[{begin:"''",end:"''"},{begin:'"',end:'"'}]},i=[e.NUMBER_MODE,e.HASH_COMMENT_MODE,e.C_BLOCK_COMMENT_MODE,t,{begin:/[a-zA-Z0-9-_]+(\s*=)/,returnBegin:!0,relevance:0,contains:[{className:"attr",begin:/\S+/}]}];return s.contains=i,{name:"Nix",aliases:["nixos"],keywords:n,contains:i}}}}]);
//# sourceMappingURL=13419.dtale_bundle.js.map