"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[56874],{62903(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a={lastWeek:"eeee 'trecută la' p",yesterday:"'ieri la' p",today:"'astăzi la' p",tomorrow:"'mâine la' p",nextWeek:"eeee 'viitoare la' p",other:"P"},l=function(e,t,l,r){return a[e]};t.default=l,e.exports=t.default}}]);
//# sourceMappingURL=56874.dtale_bundle.js.map