"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[31479],{99758(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a={lastWeek:"eeee 'إلي فات مع' p",yesterday:"'البارح مع' p",today:"'اليوم مع' p",tomorrow:"'غدوة مع' p",nextWeek:"eeee 'الجمعة الجاية مع' p 'نهار'",other:"P"},r=function(e){return a[e]};t.default=r,e.exports=t.default}}]);
//# sourceMappingURL=31479.dtale_bundle.js.map