"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[43095],{81713(e,t,a){var u=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e,t,a){(0,r.default)(2,arguments);var u=(0,d.default)(e,a),l=(0,d.default)(t,a);return u.getTime()===l.getTime()};var r=u(a(10427)),d=u(a(20930));e.exports=t.default},45518(e,t,a){var u=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var r=u(a(81713)),d=["svētdienā","pirmdienā","otrdienā","trešdienā","ceturtdienā","piektdienā","sestdienā"],l={lastWeek:function(e,t,a){return(0,r.default)(e,t,a)?"eeee 'plkst.' p":"'Pagājušā "+d[e.getUTCDay()]+" plkst.' p"},yesterday:"'Vakar plkst.' p",today:"'Šodien plkst.' p",tomorrow:"'Rīt plkst.' p",nextWeek:function(e,t,a){return(0,r.default)(e,t,a)?"eeee 'plkst.' p":"'Nākamajā "+d[e.getUTCDay()]+" plkst.' p"},other:"P"},n=function(e,t,a,u){var r=l[e];return"function"==typeof r?r(t,a,u):r};t.default=n,e.exports=t.default}}]);
//# sourceMappingURL=43095.dtale_bundle.js.map