"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[14159],{39790(e,a){Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var t={lastWeek:"eeee 'la semaine dernière à' p",yesterday:"'hier à' p",today:"'aujourd’hui à' p",tomorrow:"'demain à' p'",nextWeek:"eeee 'la semaine prochaine à' p",other:"P"},r=function(e,a,r,u){return t[e]};a.default=r,e.exports=a.default}}]);
//# sourceMappingURL=14159.dtale_bundle.js.map