"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[79905],{81713(e,a,t){var r=t(24994).default;Object.defineProperty(a,"__esModule",{value:!0}),a.default=function(e,a,t){(0,u.default)(2,arguments);var r=(0,c.default)(e,t),s=(0,c.default)(a,t);return r.getTime()===s.getTime()};var u=r(t(10427)),c=r(t(20930));e.exports=a.default},58648(e,a,t){var r=t(24994).default;Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var u=r(t(81713)),c=["недела","понеделник","вторник","среда","четврток","петок","сабота"];function s(e){var a=c[e];switch(e){case 0:case 3:case 6:return"'ова "+a+" вo' p";case 1:case 2:case 4:case 5:return"'овој "+a+" вo' p"}}var n={lastWeek:function(e,a,t){var r=e.getUTCDay();return(0,u.default)(e,a,t)?s(r):function(e){var a=c[e];switch(e){case 0:case 3:case 6:return"'минатата "+a+" во' p";case 1:case 2:case 4:case 5:return"'минатиот "+a+" во' p"}}(r)},yesterday:"'вчера во' p",today:"'денес во' p",tomorrow:"'утре во' p",nextWeek:function(e,a,t){var r=e.getUTCDay();return(0,u.default)(e,a,t)?s(r):function(e){var a=c[e];switch(e){case 0:case 3:case 6:return"'следната "+a+" вo' p";case 1:case 2:case 4:case 5:return"'следниот "+a+" вo' p"}}(r)},other:"P"},f=function(e,a,t,r){var u=n[e];return"function"==typeof u?u(a,t,r):u};a.default=f,e.exports=a.default}}]);
//# sourceMappingURL=79905.dtale_bundle.js.map