"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[3481],{52140(e,a){Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var l={about:"körülbelül",over:"több mint",almost:"majdnem",lessthan:"kevesebb mint"},t={xseconds:" másodperc",halfaminute:"fél perc",xminutes:" perc",xhours:" óra",xdays:" nap",xweeks:" hét",xmonths:" hónap",xyears:" év"},s={xseconds:{"-1":" másodperccel ezelőtt",1:" másodperc múlva",0:" másodperce"},halfaminute:{"-1":"fél perccel ezelőtt",1:"fél perc múlva",0:"fél perce"},xminutes:{"-1":" perccel ezelőtt",1:" perc múlva",0:" perce"},xhours:{"-1":" órával ezelőtt",1:" óra múlva",0:" órája"},xdays:{"-1":" nappal ezelőtt",1:" nap múlva",0:" napja"},xweeks:{"-1":" héttel ezelőtt",1:" hét múlva",0:" hete"},xmonths:{"-1":" hónappal ezelőtt",1:" hónap múlva",0:" hónapja"},xyears:{"-1":" évvel ezelőtt",1:" év múlva",0:" éve"}},r=function(e,a,r){var n=e.match(/about|over|almost|lessthan/i),o=n?e.replace(n[0],""):e,p=!0===(null==r?void 0:r.addSuffix),m=o.toLowerCase(),c=(null==r?void 0:r.comparison)||0,v=p?s[m][c]:t[m],u="halfaminute"===m?v:a+v;if(n){var d=n[0].toLowerCase();u=l[d]+" "+u}return u};a.default=r,e.exports=a.default}}]);
//# sourceMappingURL=3481.dtale_bundle.js.map