"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[64191],{87150(e,d,t){var a=t(24994).default;Object.defineProperty(d,"__esModule",{value:!0}),d.default=void 0;var l=a(t(19059)),u={date:(0,l.default)({formats:{full:"EEEE, do 'de' MMMM y",long:"y-MMMM-dd",medium:"y-MMM-dd",short:"yyyy-MM-dd"},defaultWidth:"full"}),time:(0,l.default)({formats:{full:"Ho 'horo kaj' m:ss zzzz",long:"HH:mm:ss z",medium:"HH:mm:ss",short:"HH:mm"},defaultWidth:"full"}),dateTime:(0,l.default)({formats:{any:"{{date}} {{time}}"},defaultWidth:"any"})};d.default=u,e.exports=d.default}}]);
//# sourceMappingURL=64191.dtale_bundle.js.map