"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[72713],{28128(e,t,a){var r=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var c=a(17705),u=r(a(81713)),n=["неділю","понеділок","вівторок","середу","четвер","п’ятницю","суботу"];function s(e){return"'у "+n[e]+" о' p"}var o={lastWeek:function(e,t,a){var r=(0,c.toDate)(e),o=r.getUTCDay();return(0,u.default)(r,t,a)?s(o):function(e){var t=n[e];switch(e){case 0:case 3:case 5:case 6:return"'у минулу "+t+" о' p";case 1:case 2:case 4:return"'у минулий "+t+" о' p"}}(o)},yesterday:"'вчора о' p",today:"'сьогодні о' p",tomorrow:"'завтра о' p",nextWeek:function(e,t,a){var r=(0,c.toDate)(e),o=r.getUTCDay();return(0,u.default)(r,t,a)?s(o):function(e){var t=n[e];switch(e){case 0:case 3:case 5:case 6:return"'у наступну "+t+" о' p";case 1:case 2:case 4:return"'у наступний "+t+" о' p"}}(o)},other:"P"},f=function(e,t,a,r){var c=o[e];return"function"==typeof c?c(t,a,r):c};t.default=f,e.exports=t.default}}]);
//# sourceMappingURL=72713.dtale_bundle.js.map