"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[97792],{75461(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a={lastWeek:"先週のeeeeのp",yesterday:"昨日のp",today:"今日のp",tomorrow:"明日のp",nextWeek:"翌週のeeeeのp",other:"P"},r=function(e,t,r,u){return a[e]};t.default=r,e.exports=t.default}}]);
//# sourceMappingURL=97792.dtale_bundle.js.map