"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[73884],{27377(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var r={lastWeek:function(e){switch(e.getUTCDay()){case 0:return"'прошле недеље у' p";case 3:return"'прошле среде у' p";case 6:return"'прошле суботе у' p";default:return"'прошли' EEEE 'у' p"}},yesterday:"'јуче у' p",today:"'данас у' p",tomorrow:"'сутра у' p",nextWeek:function(e){switch(e.getUTCDay()){case 0:return"'следеће недеље у' p";case 3:return"'следећу среду у' p";case 6:return"'следећу суботу у' p";default:return"'следећи' EEEE 'у' p"}},other:"P"},u=function(e,t,u,a){var n=r[e];return"function"==typeof n?n(t):n};t.default=u,e.exports=t.default}}]);
//# sourceMappingURL=73884.dtale_bundle.js.map