"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[96915],{81713(e,t,u){var r=u(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e,t,u){(0,a.default)(2,arguments);var r=(0,n.default)(e,u),f=(0,n.default)(t,u);return r.getTime()===f.getTime()};var a=r(u(10427)),n=r(u(20930));e.exports=t.default},45818(e,t,u){var r=u(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a=r(u(81713)),n=["жексенбіде","дүйсенбіде","сейсенбіде","сәрсенбіде","бейсенбіде","жұмада","сенбіде"];function f(e){return"'"+n[e]+" сағат' p'-де'"}var d={lastWeek:function(e,t,u){var r=e.getUTCDay();return(0,a.default)(e,t,u)?f(r):function(e){return"'өткен "+n[e]+" сағат' p'-де'"}(r)},yesterday:"'кеше сағат' p'-де'",today:"'бүгін сағат' p'-де'",tomorrow:"'ертең сағат' p'-де'",nextWeek:function(e,t,u){var r=e.getUTCDay();return(0,a.default)(e,t,u)?f(r):function(e){return"'келесі "+n[e]+" сағат' p'-де'"}(r)},other:"P"},l=function(e,t,u,r){var a=d[e];return"function"==typeof a?a(t,u,r):a};t.default=l,e.exports=t.default}}]);
//# sourceMappingURL=96915.dtale_bundle.js.map