(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[89118],{2538(e){e.exports=function(e){return{name:"Julia REPL",contains:[{className:"meta",begin:/^julia>/,relevance:10,starts:{end:/^(?![ ]{6})/,subLanguage:"julia"},aliases:["jldoctest"]}]}}}}]);
//# sourceMappingURL=89118.dtale_bundle.js.map