(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[33736],{35173(n){n.exports=function(n){const e={literal:"true false null"},l=[n.C_LINE_COMMENT_MODE,n.C_BLOCK_COMMENT_MODE],a=[n.QUOTE_STRING_MODE,n.C_NUMBER_MODE],i={end:",",endsWithParent:!0,excludeEnd:!0,contains:a,keywords:e},t={begin:/\{/,end:/\}/,contains:[{className:"attr",begin:/"/,end:/"/,contains:[n.BACKSLASH_ESCAPE],illegal:"\\n"},n.inherit(i,{begin:/:/})].concat(l),illegal:"\\S"},s={begin:"\\[",end:"\\]",contains:[n.inherit(i)],illegal:"\\S"};return a.push(t,s),l.forEach(function(n){a.push(n)}),{name:"JSON",contains:a,keywords:e,illegal:"\\S"}}}}]);
//# sourceMappingURL=33736.dtale_bundle.js.map