"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[94006],{62275(e,o){Object.defineProperty(o,"__esModule",{value:!0}),o.default=void 0;var t={lastWeek:function(e){switch(e.getUTCDay()){case 0:return"'prejšnjo nedeljo ob' p";case 3:return"'prejšnjo sredo ob' p";case 6:return"'prejšnjo soboto ob' p";default:return"'prejšnji' EEEE 'ob' p"}},yesterday:"'včeraj ob' p",today:"'danes ob' p",tomorrow:"'jutri ob' p",nextWeek:function(e){switch(e.getUTCDay()){case 0:return"'naslednjo nedeljo ob' p";case 3:return"'naslednjo sredo ob' p";case 6:return"'naslednjo soboto ob' p";default:return"'naslednji' EEEE 'ob' p"}},other:"P"},n=function(e,o,n,r){var a=t[e];return"function"==typeof a?a(o):a};o.default=n,e.exports=o.default}}]);
//# sourceMappingURL=94006.dtale_bundle.js.map