"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[7840,32907],{47365(e,t,a){var d=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var l=d(a(19059)),f={date:(0,l.default)({formats:{full:"EEEE, d MMMM yyyy",long:"d MMMM, yyyy",medium:"d MMM, yyyy",short:"dd/MM/yyyy"},defaultWidth:"full"}),time:(0,l.default)({formats:{full:"h:mm:ss a zzzz",long:"h:mm:ss a z",medium:"h:mm:ss a",short:"h:mm a"},defaultWidth:"full"}),dateTime:(0,l.default)({formats:{full:"{{date}} 'at' {{time}}",long:"{{date}} 'at' {{time}}",medium:"{{date}}, {{time}}",short:"{{date}}, {{time}}"},defaultWidth:"full"})};t.default=f,e.exports=t.default},60734(e,t,a){var d=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var l=d(a(91287)),f=d(a(26376)),u=d(a(12568)),m=d(a(85024)),o=d(a(47365)),s={code:"en-IN",formatDistance:l.default,formatLong:o.default,formatRelative:f.default,localize:u.default,match:m.default,options:{weekStartsOn:1,firstWeekContainsDate:4}};t.default=s,e.exports=t.default}}]);
//# sourceMappingURL=32907.dtale_bundle.js.map