(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[45253],{63929(e){e.exports=function(e){return{name:"Clojure REPL",contains:[{className:"meta",begin:/^([\w.-]+|\s*#_)?=>/,starts:{end:/$/,subLanguage:"clojure"}}]}}}}]);
//# sourceMappingURL=45253.dtale_bundle.js.map