"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[21124],{81713(e,t,a){var r=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e,t,a){(0,l.default)(2,arguments);var r=(0,u.default)(e,a),o=(0,u.default)(t,a);return r.getTime()===o.getTime()};var l=r(a(10427)),u=r(a(20930));e.exports=t.default},27441(e,t,a){var r=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var l=r(a(81713)),u=["domenica","lunedì","martedì","mercoledì","giovedì","venerdì","sabato"];function o(e){return"'"+u[e]+" alle' p"}var n={lastWeek:function(e,t,a){var r=e.getUTCDay();return(0,l.default)(e,t,a)?o(r):function(e){return 0===e?"'domenica scorsa alle' p":"'"+u[e]+" scorso alle' p"}(r)},yesterday:"'ieri alle' p",today:"'oggi alle' p",tomorrow:"'domani alle' p",nextWeek:function(e,t,a){var r=e.getUTCDay();return(0,l.default)(e,t,a)?o(r):function(e){return 0===e?"'domenica prossima alle' p":"'"+u[e]+" prossimo alle' p"}(r)},other:"P"},d=function(e,t,a,r){var l=n[e];return"function"==typeof l?l(t,a,r):l};t.default=d,e.exports=t.default}}]);
//# sourceMappingURL=21124.dtale_bundle.js.map