"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[63995],{81713(e,t,u){var a=u(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e,t,u){(0,r.default)(2,arguments);var a=(0,o.default)(e,u),n=(0,o.default)(t,u);return a.getTime()===n.getTime()};var r=a(u(10427)),o=a(u(20930));e.exports=t.default},95349(e,t,u){var a=u(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var r=a(u(81713)),o=["nedeľu","pondelok","utorok","stredu","štvrtok","piatok","sobotu"];function n(e){return 4===e?"'vo' eeee 'o' p":"'v "+o[e]+" o' p"}var d={lastWeek:function(e,t,u){var a=e.getUTCDay();return(0,r.default)(e,t,u)?n(a):function(e){var t=o[e];switch(e){case 0:case 3:case 6:return"'minulú "+t+" o' p";default:return"'minulý' eeee 'o' p"}}(a)},yesterday:"'včera o' p",today:"'dnes o' p",tomorrow:"'zajtra o' p",nextWeek:function(e,t,u){var a=e.getUTCDay();return(0,r.default)(e,t,u)?n(a):function(e){var t=o[e];switch(e){case 0:case 4:case 6:return"'budúcu "+t+" o' p";default:return"'budúci' eeee 'o' p"}}(a)},other:"P"},f=function(e,t,u,a){var r=d[e];return"function"==typeof r?r(t,u,a):r};t.default=f,e.exports=t.default}}]);
//# sourceMappingURL=63995.dtale_bundle.js.map