"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[79002],{98399(e,a){Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var t={lastWeek:"'mu dheireadh' eeee 'aig' p",yesterday:"'an-dè aig' p",today:"'an-diugh aig' p",tomorrow:"'a-màireach aig' p",nextWeek:"eeee 'aig' p",other:"P"},d=function(e,a,d,r){return t[e]};a.default=d,e.exports=a.default}}]);
//# sourceMappingURL=79002.dtale_bundle.js.map