"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[27886],{63027(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a={lastWeek:"eeee 'الماضي عند الساعة' p",yesterday:"'الأمس عند الساعة' p",today:"'اليوم عند الساعة' p",tomorrow:"'غدا عند الساعة' p",nextWeek:"eeee 'القادم عند الساعة' p",other:"P"},r=function(e){return a[e]};t.default=r,e.exports=t.default}}]);
//# sourceMappingURL=27886.dtale_bundle.js.map