"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[28115],{79622(e,n){Object.defineProperty(n,"__esModule",{value:!0}),n.default=void 0;var t={lessThanXSeconds:{one:"mindre än en sekund",other:"mindre än {{count}} sekunder"},xSeconds:{one:"en sekund",other:"{{count}} sekunder"},halfAMinute:"en halv minut",lessThanXMinutes:{one:"mindre än en minut",other:"mindre än {{count}} minuter"},xMinutes:{one:"en minut",other:"{{count}} minuter"},aboutXHours:{one:"ungefär en timme",other:"ungefär {{count}} timmar"},xHours:{one:"en timme",other:"{{count}} timmar"},xDays:{one:"en dag",other:"{{count}} dagar"},aboutXWeeks:{one:"ungefär en vecka",other:"ungefär {{count}} vecka"},xWeeks:{one:"en vecka",other:"{{count}} vecka"},aboutXMonths:{one:"ungefär en månad",other:"ungefär {{count}} månader"},xMonths:{one:"en månad",other:"{{count}} månader"},aboutXYears:{one:"ungefär ett år",other:"ungefär {{count}} år"},xYears:{one:"ett år",other:"{{count}} år"},overXYears:{one:"över ett år",other:"över {{count}} år"},almostXYears:{one:"nästan ett år",other:"nästan {{count}} år"}},o=["noll","en","två","tre","fyra","fem","sex","sju","åtta","nio","tio","elva","tolv"],r=function(e,n,r){var u,a=t[e];return u="string"==typeof a?a:1===n?a.one:r&&r.onlyNumeric?a.other.replace("{{count}}",String(n)):a.other.replace("{{count}}",n<13?o[n]:String(n)),null!=r&&r.addSuffix?r.comparison&&r.comparison>0?"om "+u:u+" sedan":u};n.default=r,e.exports=n.default}}]);
//# sourceMappingURL=28115.dtale_bundle.js.map