"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[22187],{81713(e,t,a){var u=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e,t,a){(0,r.default)(2,arguments);var u=(0,d.default)(e,a),f=(0,d.default)(t,a);return u.getTime()===f.getTime()};var r=u(a(10427)),d=u(a(20930));e.exports=t.default},24538(e,t,a){var u=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var r=u(a(81713));function d(e,t,a){var u="eeee p";return(0,r.default)(e,t,a)?u:e.getTime()>t.getTime()?"'下个'"+u:"'上个'"+u}var f={lastWeek:d,yesterday:"'昨天' p",today:"'今天' p",tomorrow:"'明天' p",nextWeek:d,other:"PP p"},l=function(e,t,a,u){var r=f[e];return"function"==typeof r?r(t,a,u):r};t.default=l,e.exports=t.default}}]);
//# sourceMappingURL=22187.dtale_bundle.js.map