"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[93201],{33240(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var l={lastWeek:"'forrige' eeee 'kl.' p",yesterday:"'i går kl.' p",today:"'i dag kl.' p",tomorrow:"'i morgen kl.' p",nextWeek:"EEEE 'kl.' p",other:"P"},r=function(e,t,r,a){return l[e]};t.default=r,e.exports=t.default}}]);
//# sourceMappingURL=93201.dtale_bundle.js.map