"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[4374],{16619(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var u={lastWeek:"'letzten' eeee 'um' p",yesterday:"'gestern um' p",today:"'heute um' p",tomorrow:"'morgen um' p",nextWeek:"eeee 'um' p",other:"P"},r=function(e,t,r,a){return u[e]};t.default=r,e.exports=t.default}}]);
//# sourceMappingURL=4374.dtale_bundle.js.map