"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[62415],{13686(u,e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0;var t={lastWeek:function(u){switch(u.getUTCDay()){case 0:return"'prošlu nedjelju u' p";case 3:return"'prošlu srijedu u' p";case 6:return"'prošlu subotu u' p";default:return"'prošli' EEEE 'u' p"}},yesterday:"'jučer u' p",today:"'danas u' p",tomorrow:"'sutra u' p",nextWeek:function(u){switch(u.getUTCDay()){case 0:return"'iduću nedjelju u' p";case 3:return"'iduću srijedu u' p";case 6:return"'iduću subotu u' p";default:return"'prošli' EEEE 'u' p"}},other:"P"},r=function(u,e,r,a){var n=t[u];return"function"==typeof n?n(e):n};e.default=r,u.exports=e.default}}]);
//# sourceMappingURL=62415.dtale_bundle.js.map