"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[12005],{51472(e,o){Object.defineProperty(o,"__esModule",{value:!0}),o.default=void 0;var t={lessThanXSeconds:{one:"секунд хүрэхгүй",other:"{{count}} секунд хүрэхгүй"},xSeconds:{one:"1 секунд",other:"{{count}} секунд"},halfAMinute:"хагас минут",lessThanXMinutes:{one:"минут хүрэхгүй",other:"{{count}} минут хүрэхгүй"},xMinutes:{one:"1 минут",other:"{{count}} минут"},aboutXHours:{one:"ойролцоогоор 1 цаг",other:"ойролцоогоор {{count}} цаг"},xHours:{one:"1 цаг",other:"{{count}} цаг"},xDays:{one:"1 өдөр",other:"{{count}} өдөр"},aboutXWeeks:{one:"ойролцоогоор 1 долоо хоног",other:"ойролцоогоор {{count}} долоо хоног"},xWeeks:{one:"1 долоо хоног",other:"{{count}} долоо хоног"},aboutXMonths:{one:"ойролцоогоор 1 сар",other:"ойролцоогоор {{count}} сар"},xMonths:{one:"1 сар",other:"{{count}} сар"},aboutXYears:{one:"ойролцоогоор 1 жил",other:"ойролцоогоор {{count}} жил"},xYears:{one:"1 жил",other:"{{count}} жил"},overXYears:{one:"1 жил гаран",other:"{{count}} жил гаран"},almostXYears:{one:"бараг 1 жил",other:"бараг {{count}} жил"}},n=function(e,o,n){var r,a=t[e];if(r="string"==typeof a?a:1===o?a.one:a.other.replace("{{count}}",String(o)),null!=n&&n.addSuffix){var s=r.split(" "),u=s.pop();switch(r=s.join(" "),u){case"секунд":r+=" секундийн";break;case"минут":r+=" минутын";break;case"цаг":r+=" цагийн";break;case"өдөр":r+=" өдрийн";break;case"сар":r+=" сарын";break;case"жил":r+=" жилийн";break;case"хоног":r+=" хоногийн";break;case"гаран":r+=" гараны";break;case"хүрэхгүй":r+=" хүрэхгүй хугацааны";break;default:r+=u+"-н"}return n.comparison&&n.comparison>0?r+" дараа":r+" өмнө"}return r};o.default=n,e.exports=o.default}}]);
//# sourceMappingURL=12005.dtale_bundle.js.map