"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[17026],{81713(e,t,a){var r=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=function(e,t,a){(0,u.default)(2,arguments);var r=(0,n.default)(e,a),c=(0,n.default)(t,a);return r.getTime()===c.getTime()};var u=r(a(10427)),n=r(a(20930));e.exports=t.default},54399(e,t,a){var r=a(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var u=r(a(17420)),n=r(a(81713)),c=["неделя","понеделник","вторник","сряда","четвъртък","петък","събота"];function f(e){var t=c[e];return 2===e?"'във "+t+" в' p":"'в "+t+" в' p"}var s={lastWeek:function(e,t,a){var r=(0,u.default)(e),s=r.getUTCDay();return(0,n.default)(r,t,a)?f(s):function(e){var t=c[e];switch(e){case 0:case 3:case 6:return"'миналата "+t+" в' p";case 1:case 2:case 4:case 5:return"'миналия "+t+" в' p"}}(s)},yesterday:"'вчера в' p",today:"'днес в' p",tomorrow:"'утре в' p",nextWeek:function(e,t,a){var r=(0,u.default)(e),s=r.getUTCDay();return(0,n.default)(r,t,a)?f(s):function(e){var t=c[e];switch(e){case 0:case 3:case 6:return"'следващата "+t+" в' p";case 1:case 2:case 4:case 5:return"'следващия "+t+" в' p"}}(s)},other:"P"},d=function(e,t,a,r){var u=s[e];return"function"==typeof u?u(t,a,r):u};t.default=d,e.exports=t.default}}]);
//# sourceMappingURL=17026.dtale_bundle.js.map