"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[1226],{63271(e,a){Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var t={lastWeek:"'oldingi' eeee p 'da'",yesterday:"'kecha' p 'da'",today:"'bugun' p 'da'",tomorrow:"'ertaga' p 'da'",nextWeek:"eeee p 'da'",other:"P"},d=function(e,a,d,u){return t[e]};a.default=d,e.exports=a.default}}]);
//# sourceMappingURL=1226.dtale_bundle.js.map