"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[76772],{6929(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var l={lastWeek:"'viime' eeee 'klo' p",yesterday:"'eilen klo' p",today:"'tänään klo' p",tomorrow:"'huomenna klo' p",nextWeek:"'ensi' eeee 'klo' p",other:"P"},o=function(e,t,o,a){return l[e]};t.default=o,e.exports=t.default}}]);
//# sourceMappingURL=76772.dtale_bundle.js.map