"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[13634],{29287(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var o={lastWeek:"'o' eeee 'pasado á' LT",yesterday:"'onte á' p",today:"'hoxe á' p",tomorrow:"'mañá á' p",nextWeek:"eeee 'á' p",other:"P"},a={lastWeek:"'o' eeee 'pasado ás' p",yesterday:"'onte ás' p",today:"'hoxe ás' p",tomorrow:"'mañá ás' p",nextWeek:"eeee 'ás' p",other:"P"},s=function(e,t,s,p){return 1!==t.getUTCHours()?a[e]:o[e]};t.default=s,e.exports=t.default}}]);
//# sourceMappingURL=13634.dtale_bundle.js.map