"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[14302],{10419(e,t,d){var l=d(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a=l(d(19059)),u={date:(0,a.default)({formats:{full:"EEEE, d MMMM y 'г.'",long:"d MMMM y 'г.'",medium:"d MMM y 'г.'",short:"dd.MM.y"},defaultWidth:"full"}),time:(0,a.default)({formats:{full:"H:mm:ss zzzz",long:"H:mm:ss z",medium:"H:mm:ss",short:"H:mm"},defaultWidth:"full"}),dateTime:(0,a.default)({formats:{any:"{{date}}, {{time}}"},defaultWidth:"any"})};t.default=u,e.exports=t.default}}]);
//# sourceMappingURL=14302.dtale_bundle.js.map