"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[82545],{93744(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a={lastWeek:"eeee 'diwethaf am' p",yesterday:"'ddoe am' p",today:"'heddiw am' p",tomorrow:"'yfory am' p",nextWeek:"eeee 'am' p",other:"P"},d=function(e,t,d,o){return a[e]};t.default=d,e.exports=t.default}}]);
//# sourceMappingURL=82545.dtale_bundle.js.map