"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[845],{26844(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a={lastWeek:"'pasinta' eeee 'je' p",yesterday:"'hieraŭ je' p",today:"'hodiaŭ je' p",tomorrow:"'morgaŭ je' p",nextWeek:"eeee 'je' p",other:"P"},r=function(e,t,r,o){return a[e]};t.default=r,e.exports=t.default}}]);
//# sourceMappingURL=845.dtale_bundle.js.map