"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[93747],{37114(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var r=["neděli","pondělí","úterý","středu","čtvrtek","pátek","sobotu"],o={lastWeek:"'poslední' eeee 've' p",yesterday:"'včera v' p",today:"'dnes v' p",tomorrow:"'zítra v' p",nextWeek:function(e){var t=e.getUTCDay();return"'v "+r[t]+" o' p"},other:"P"},a=function(e,t){var r=o[e];return"function"==typeof r?r(t):r};t.default=a,e.exports=t.default}}]);
//# sourceMappingURL=93747.dtale_bundle.js.map