"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[3241],{44616(e,t,d){var l=d(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a=l(d(19059)),m={date:(0,a.default)({formats:{full:"EEEE d MMMM y",long:"d MMMM y",medium:"d MMM y",short:"dd.MM.y"},defaultWidth:"full"}),time:(0,a.default)({formats:{full:"HH:mm:ss zzzz",long:"HH:mm:ss z",medium:"HH:mm:ss",short:"HH:mm"},defaultWidth:"full"}),dateTime:(0,a.default)({formats:{full:"{{date}} 'om' {{time}}",long:"{{date}} 'om' {{time}}",medium:"{{date}}, {{time}}",short:"{{date}}, {{time}}"},defaultWidth:"full"})};t.default=m,e.exports=t.default}}]);
//# sourceMappingURL=3241.dtale_bundle.js.map