"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[62176],{42805(e,l){Object.defineProperty(l,"__esModule",{value:!0}),l.default=void 0;var t={lastWeek:"eeee 'li għadda' 'fil-'p",yesterday:"'Il-bieraħ fil-'p",today:"'Illum fil-'p",tomorrow:"'Għada fil-'p",nextWeek:"eeee 'fil-'p",other:"P"},a=function(e,l,a,d){return t[e]};l.default=a,e.exports=l.default}}]);
//# sourceMappingURL=62176.dtale_bundle.js.map