"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[70893],{75388(e,t,d){var l=d(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a=l(d(19059)),u={date:(0,a.default)({formats:{full:"y년 M월 d일 EEEE",long:"y년 M월 d일",medium:"y.MM.dd",short:"y.MM.dd"},defaultWidth:"full"}),time:(0,a.default)({formats:{full:"a H시 mm분 ss초 zzzz",long:"a H:mm:ss z",medium:"HH:mm:ss",short:"HH:mm"},defaultWidth:"full"}),dateTime:(0,a.default)({formats:{full:"{{date}} {{time}}",long:"{{date}} {{time}}",medium:"{{date}} {{time}}",short:"{{date}} {{time}}"},defaultWidth:"full"})};t.default=u,e.exports=t.default}}]);
//# sourceMappingURL=70893.dtale_bundle.js.map