"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[60729],{51256(e,a){Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var t={lastWeek:"'el' eeee 'passat a la' LT",yesterday:"'ahir a la' p",today:"'avui a la' p",tomorrow:"'demà a la' p",nextWeek:"eeee 'a la' p",other:"P"},l={lastWeek:"'el' eeee 'passat a les' p",yesterday:"'ahir a les' p",today:"'avui a les' p",tomorrow:"'demà a les' p",nextWeek:"eeee 'a les' p",other:"P"},s=function(e,a,s,r){return 1!==a.getUTCHours()?l[e]:t[e]};a.default=s,e.exports=a.default}}]);
//# sourceMappingURL=60729.dtale_bundle.js.map