"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[31931],{28906(e,t,d){var l=d(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a=l(d(19059)),u={date:(0,a.default)({formats:{full:"EEEE, do MMMM, y",long:"do, MMMM, y",medium:"d, MMM, y",short:"dd/MM/yyyy"},defaultWidth:"full"}),time:(0,a.default)({formats:{full:"h:mm:ss a zzzz",long:"h:mm:ss a z",medium:"h:mm:ss a",short:"h:mm a"},defaultWidth:"full"}),dateTime:(0,a.default)({formats:{full:"{{date}} {{time}}'-ზე'",long:"{{date}} {{time}}'-ზე'",medium:"{{date}}, {{time}}",short:"{{date}}, {{time}}"},defaultWidth:"full"})};t.default=u,e.exports=t.default}}]);
//# sourceMappingURL=31931.dtale_bundle.js.map