"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[37231],{30999(e,t,a){a.r(t),a.d(t,{splitPathsBySizeLoader:()=>i});var n=a(43261),s=a(6134);const i=async(e,t)=>{const i=(0,n.fL)(e);let l;return l=t===s.l.STANDARD?await a.e(79672).then(a.bind(a,10773)):await a.e(94783).then(a.bind(a,6950)),l[i]}}}]);
//# sourceMappingURL=37231.dtale_bundle.js.map