"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[88850],{63468(e,t,d){var l=d(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a=l(d(19059)),u={date:(0,a.default)({formats:{full:"y年M月d日EEEE",long:"y年M月d日",medium:"y/MM/dd",short:"y/MM/dd"},defaultWidth:"full"}),time:(0,a.default)({formats:{full:"H時mm分ss秒 zzzz",long:"H:mm:ss z",medium:"H:mm:ss",short:"H:mm"},defaultWidth:"full"}),dateTime:(0,a.default)({formats:{full:"{{date}} {{time}}",long:"{{date}} {{time}}",medium:"{{date}} {{time}}",short:"{{date}} {{time}}"},defaultWidth:"full"})};t.default=u,e.exports=t.default}}]);
//# sourceMappingURL=88850.dtale_bundle.js.map