"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[87786],{27631(e,a,t){var r=t(24994).default;Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var u=r(t(51545));function d(e,a,t,r,u){var d=function(e){return"quarter"===e}(a)?u:function(e){return"year"===e||"week"===e||"minute"===e||"second"===e}(a)?r:t;return e+"-"+d}var n={ordinalNumber:function(e,a){var t=Number(e),r=null==a?void 0:a.unit;if(0===t)return d(0,r,"ев","ева","ево");if(t%1e3==0)return d(t,r,"ен","на","но");if(t%100==0)return d(t,r,"тен","тна","тно");var u=t%100;if(u>20||u<10)switch(u%10){case 1:return d(t,r,"ви","ва","во");case 2:return d(t,r,"ри","ра","ро");case 7:case 8:return d(t,r,"ми","ма","мо")}return d(t,r,"ти","та","то")},era:(0,u.default)({values:{narrow:["пр.н.е.","н.е."],abbreviated:["преди н. е.","н. е."],wide:["преди новата ера","новата ера"]},defaultWidth:"wide"}),quarter:(0,u.default)({values:{narrow:["1","2","3","4"],abbreviated:["1-во тримес.","2-ро тримес.","3-то тримес.","4-то тримес."],wide:["1-во тримесечие","2-ро тримесечие","3-то тримесечие","4-то тримесечие"]},defaultWidth:"wide",argumentCallback:function(e){return e-1}}),month:(0,u.default)({values:{abbreviated:["яну","фев","мар","апр","май","юни","юли","авг","сеп","окт","ное","дек"],wide:["януари","февруари","март","април","май","юни","юли","август","септември","октомври","ноември","декември"]},defaultWidth:"wide"}),day:(0,u.default)({values:{narrow:["Н","П","В","С","Ч","П","С"],short:["нд","пн","вт","ср","чт","пт","сб"],abbreviated:["нед","пон","вто","сря","чет","пет","съб"],wide:["неделя","понеделник","вторник","сряда","четвъртък","петък","събота"]},defaultWidth:"wide"}),dayPeriod:(0,u.default)({values:{wide:{am:"преди обяд",pm:"след обяд",midnight:"в полунощ",noon:"на обяд",morning:"сутринта",afternoon:"следобед",evening:"вечерта",night:"през нощта"}},defaultWidth:"wide"})};a.default=n,e.exports=a.default}}]);
//# sourceMappingURL=87786.dtale_bundle.js.map