(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[56152],{25356(e){e.exports=function(e){return{name:"VBScript in HTML",subLanguage:"xml",contains:[{begin:"<%",end:"%>",subLanguage:"vbscript"}]}}}}]);
//# sourceMappingURL=56152.dtale_bundle.js.map