"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[34609],{55480(e,a){Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var t={lastWeek:"'el' eeee 'pasado a la' p",yesterday:"'ayer a la' p",today:"'hoy a la' p",tomorrow:"'mañana a la' p",nextWeek:"eeee 'a la' p",other:"P"},l={lastWeek:"'el' eeee 'pasado a las' p",yesterday:"'ayer a las' p",today:"'hoy a las' p",tomorrow:"'mañana a las' p",nextWeek:"eeee 'a las' p",other:"P"},o=function(e,a,o,s){return 1!==a.getUTCHours()?l[e]:t[e]};a.default=o,e.exports=a.default}}]);
//# sourceMappingURL=34609.dtale_bundle.js.map