"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[69545],{6384(e,a){Object.defineProperty(a,"__esModule",{value:!0}),a.default=void 0;var t={lastWeek:"eeee 'lepas pada jam' p",yesterday:"'Semalam pada jam' p",today:"'Hari ini pada jam' p",tomorrow:"'Esok pada jam' p",nextWeek:"eeee 'pada jam' p",other:"P"},p=function(e,a,p,d){return t[e]};a.default=p,e.exports=a.default}}]);
//# sourceMappingURL=69545.dtale_bundle.js.map