(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[30464],{32117(e){e.exports=function(e){return{name:"Shell Session",aliases:["console"],contains:[{className:"meta",begin:/^\s{0,3}[/~\w\d[\]()@-]*[>%$#]/,starts:{end:/[^\\](?=\s*$)/,subLanguage:"bash"}}]}}}}]);
//# sourceMappingURL=30464.dtale_bundle.js.map