"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[48975],{28102(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var a={lastWeek:"'joan den' eeee, LT",yesterday:"'atzo,' p",today:"'gaur,' p",tomorrow:"'bihar,' p",nextWeek:"eeee, p",other:"P"},o={lastWeek:"'joan den' eeee, p",yesterday:"'atzo,' p",today:"'gaur,' p",tomorrow:"'bihar,' p",nextWeek:"eeee, p",other:"P"},r=function(e,t){return 1!==t.getUTCHours()?o[e]:a[e]};t.default=r,e.exports=t.default}}]);
//# sourceMappingURL=48975.dtale_bundle.js.map