"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[28451],{79562(e,t,l){var d=l(24994).default;Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var u=d(l(19059)),a={date:(0,u.default)({formats:{full:"EEEE, d MMMM yyyy",long:"d MMMM yyyy",medium:"d MMM yyyy",short:"d/M/yyyy"},defaultWidth:"full"}),time:(0,u.default)({formats:{full:"HH.mm.ss",long:"HH.mm.ss",medium:"HH.mm",short:"HH.mm"},defaultWidth:"full"}),dateTime:(0,u.default)({formats:{full:"{{date}} 'pukul' {{time}}",long:"{{date}} 'pukul' {{time}}",medium:"{{date}}, {{time}}",short:"{{date}}, {{time}}"},defaultWidth:"full"})};t.default=a,e.exports=t.default}}]);
//# sourceMappingURL=28451.dtale_bundle.js.map