"use strict";(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[72752],{93053(e,t){Object.defineProperty(t,"__esModule",{value:!0}),t.default=void 0;var l={lastWeek:"'i' EEEE's kl.' p",yesterday:"'igår kl.' p",today:"'idag kl.' p",tomorrow:"'imorgon kl.' p",nextWeek:"EEEE 'kl.' p",other:"P"},a=function(e,t,a,r){return l[e]};t.default=a,e.exports=t.default}}]);
//# sourceMappingURL=72752.dtale_bundle.js.map