(self.webpackChunkdtale=self.webpackChunkdtale||[]).push([[53811],{57084(e){e.exports=function(e){return{name:"ERB",subLanguage:"xml",contains:[e.COMMENT("<%#","%>"),{begin:"<%[%=-]?",end:"[%-]?%>",subLanguage:"ruby",excludeBegin:!0,excludeEnd:!0}]}}}}]);
//# sourceMappingURL=53811.dtale_bundle.js.map